Learn R Programming

spinebil (version 1.0.5)

distance_to_sp: Collecting distances between input planes and input special plane.

Description

If the optimal view is known, we can use the distance between a given plane and the optimal one as a proxy to diagnose the performance of the guided tour.

Usage

distance_to_sp(planes, special_plane)

Value

numeric vector containing all distances

Arguments

planes

Input planes (e.g. result of guided tour)

special_plane

Plane defining the optimal view

Examples

Run this code
planes <- purrr::rerun(10, tourr::basis_random(5))
special_plane <- basis_matrix(1,2,5)
d <- distance_to_sp(planes, special_plane)
plot(d)

Run the code above in your browser using DataLab