These are convenicence functions that format scagnostics and mine index functions for direct use with the guided tour or other functionalities in this package.
scagIndex(indexName)mineIndex(indexName)
mineIndexE(indexName)
holesR()
cmassR()
function taking 2-d data matrix and returning the index value
Index name to select from group of indexes.
scagIndex(): Scagnostics index from binostics package
mineIndex(): MINE index from minerva package
mineIndexE(): MINE index from minerva package (updated estimator)
holesR(): rescaling the tourr holes index
cmassR(): rescaling the tourr cmass index