These are convenicence functions that format scagnostics and mine index functions for direct use with the guided tour or other functionalities in this package.
scag_index(index_name)mine_index(index_name)
mine_indexE(index_name)
holesR()
cmassR()
function taking 2-d data matrix and returning the index value
Index name to select from group of indexes.
scag_index(): Scagnostics index from cassowaryr package
mine_index(): MINE index from minerva package
mine_indexE(): MINE index from minerva package (updated estimator)
holesR(): rescaling the tourr holes index
cmassR(): rescaling the tourr cmass index